@@ -3,9 +3,7 @@ package MarpaX::Demo::StringParser::Actions;
 use strict;
 use utf8;
 use warnings;
-use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
-use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
-use charnames qw(:full :short);  # Unneeded in v5.16.
+use warnings qw(FATAL utf8); # Fatalize encoding glitches.
 
 use Set::Array;
 
@@ -17,7 +15,7 @@ use Set::Array;
 
 our $verbose;
 
-our $VERSION = '1.05';
+our $VERSION = '1.08';
 
 # --------------------------------------------------
 
