@@ -3,9 +3,7 @@ package MarpaX::Demo::StringParser::Config;
 use strict;
 use utf8;
 use warnings;
-use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
-use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
-use charnames qw(:full :short);  # Unneeded in v5.16.
+use warnings qw(FATAL utf8); # Fatalize encoding glitches.
 
 use Config::Tiny;
 
@@ -39,7 +37,7 @@ has section =>
 	required => 0,
 );
 
-our $VERSION = '1.05';
+our $VERSION = '1.08';
 
 # -----------------------------------------------
 
